@@ -12,28 +12,29 @@ URIPrefix = TypedDict('URIPrefix', {
     "connector": str,
     "address": str,
 })
-DagDef = TypedDict('DagDef', {
+BaseDagDef = TypedDict('BaseDagDef', {
     "company": str,
-    "default_input_key": Optional[str],
-    "default_output_key": Optional[str],
     "high_priority": bool,
     "name": str,
     "nodes": List['NodeDef'],
     "queue_mng": Optional[str],
-    "uri_prefix": URIPrefix,
-    "state_uri": str,
 })
-UserDagDef = TypedDict('UserDagDef', {
-    "company": str,
-    "default_input_key": Optional[str],
-    "default_output_key": Optional[str],
-    "high_priority": bool,
-    "name": str,
-    "nodes": List['NodeDef'],
-    "queue_mng": Optional[str],
-    "uri_prefix": URIPrefix,
-    "state_uri": str,
-}, total=False)
+
+
+class UserDagDef(BaseDagDef, total=False):
+    default_input_key: Optional[str]
+    default_output_key: Optional[str]
+    uri_prefix: URIPrefix
+    state_uri: str
+
+
+class DagDef(BaseDagDef):
+    default_input_key: Optional[str]
+    default_output_key: Optional[str]
+    uri_prefix: URIPrefix
+    state_uri: str
+
+
 NodeDef = TypedDict('NodeDef', {
     "blobs": Dict[str, str],
     "id": str,
@@ -438,6 +439,7 @@ BlobTypeResponse = TypedDict('BlobTypeResponse', {
     "is_csv": bool,
     "is_custom_code": bool,
     "is_json": bool,
+    "is_torch": bool,
     "type": str,
 })
 UUIDResponse = TypedDict('UUIDResponse', {
